@@ -1,6 +1,6 @@
 package GeoIP2::Record::Traits;
 {
-  $GeoIP2::Record::Traits::VERSION = '0.040000';
+  $GeoIP2::Record::Traits::VERSION = '0.040001';
 }
 BEGIN {
   $GeoIP2::Record::Traits::AUTHORITY = 'cpan:TJMATHER';
@@ -41,13 +41,13 @@ has domain => (
 has is_anonymous_proxy => (
     is      => 'ro',
     isa     => Bool,
-    default => quote_sub(q{ 0 })
+    default => quote_sub(q{ 0 }),
 );
 
 has is_satellite_provider => (
     is      => 'ro',
     isa     => Bool,
-    default => quote_sub(q{ 0 })
+    default => quote_sub(q{ 0 }),
 );
 
 has isp => (
@@ -82,7 +82,7 @@ GeoIP2::Record::Traits - Contains data for the traits record associated with an
 
 =head1 VERSION
 
-version 0.040000
+version 0.040001
 
 =head1 SYNOPSIS
 
@@ -233,7 +233,7 @@ Graham Knop <haarg@haarg.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by MaxMind, Inc..
+This software is copyright (c) 2014 by MaxMind, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
