@@ -1,6 +1,6 @@
 package GeoIP2::Role::Model;
 {
-  $GeoIP2::Role::Model::VERSION = '0.040000';
+  $GeoIP2::Role::Model::VERSION = '0.040001';
 }
 BEGIN {
   $GeoIP2::Role::Model::AUTHORITY = 'cpan:TJMATHER';
@@ -22,7 +22,7 @@ use Sub::Quote qw( quote_sub );
 
 use Moo::Role;
 
-with 'GeoIP2::Role::HasLanguages';
+with 'GeoIP2::Role::HasLocales';
 
 has raw => (
     is       => 'ro',
@@ -110,7 +110,7 @@ sub _build_record {
     my $raw = $self->$method();
 
     return $self->_record_class_for_key($key)
-        ->new( %{$raw}, languages => $self->languages() );
+        ->new( %{$raw}, locales => $self->locales() );
 }
 
 {
