@@ -1,6 +1,6 @@
 package GeoIP2::Role::Record::HasNames;
 {
-  $GeoIP2::Role::Record::HasNames::VERSION = '0.040000';
+  $GeoIP2::Role::Record::HasNames::VERSION = '0.040001';
 }
 BEGIN {
   $GeoIP2::Role::Record::HasNames::AUTHORITY = 'cpan:TJMATHER';
@@ -15,7 +15,7 @@ use Sub::Quote qw( quote_sub );
 
 use Moo::Role;
 
-with 'GeoIP2::Role::HasLanguages';
+with 'GeoIP2::Role::HasLocales';
 
 has name => (
     is      => 'ro',
@@ -35,7 +35,7 @@ sub _build_name {
 
     my $names = $self->names();
 
-    my $lang = first { exists $names->{$_} } @{ $self->languages() };
+    my $lang = first { exists $names->{$_} } @{ $self->locales() };
 
     return unless $lang;
     return $names->{$lang};
