@@ -1,6 +1,6 @@
 package GeoIP2::WebService::Client;
 {
-  $GeoIP2::WebService::Client::VERSION = '0.040000';
+  $GeoIP2::WebService::Client::VERSION = '0.040001';
 }
 BEGIN {
   $GeoIP2::WebService::Client::AUTHORITY = 'cpan:TJMATHER';
@@ -34,7 +34,7 @@ use URI;
 
 use Moo;
 
-with 'GeoIP2::Role::HasLanguages';
+with 'GeoIP2::Role::HasLocales';
 
 has user_id => (
     is       => 'ro',
@@ -169,7 +169,7 @@ sub _response_for {
         my $body = $self->_handle_success( $response, $uri );
         return $model_class->new(
             %{$body},
-            languages => $self->languages(),
+            locales => $self->locales(),
         );
     }
     else {
@@ -329,7 +329,7 @@ GeoIP2::WebService::Client - Perl API for the GeoIP2 web service end points
 
 =head1 VERSION
 
-version 0.040000
+version 0.040001
 
 =head1 SYNOPSIS
 
@@ -337,11 +337,16 @@ version 0.040000
 
   use GeoIP2::WebService::Client;
 
+  # This creates a Client object that can be reused across requests.
+  # Replace "42" with your user id and "abcdef123456" with your license
+  # key.
   my $client = GeoIP2::WebService::Client->new(
       user_id     => 42,
       license_key => 'abcdef123456',
   );
 
+  # Replace "omni" with the method corresponding to the web service
+  # that you are using, e.g., "country", "city_isp_org", "city".
   my $omni = $client->omni( ip => '24.24.24.24' );
 
   my $country = $omni->country();
@@ -405,21 +410,21 @@ see your MaxMind User ID and license key.
 
 This argument is required.
 
-=item * languages
+=item * locales
 
-This is an array reference where each value is a string indicating a
-language. This argument will be passed onto record classes to use when their
-C<name()> methods are called.
+This is an array reference where each value is a string indicating a locale.
+This argument will be passed onto record classes to use when their C<name()>
+methods are called.
 
-The order of the languages is significant. When a record class has multiple
+The order of the locales is significant. When a record class has multiple
 names (country, city, etc.), its C<name()> method will look at each element of
-this array ref and return the first language for which it has a name.
+this array ref and return the first locale for which it has a name.
 
-Note that the only language which is always present in the GeoIP2 data in
-"en". If you do not include this language, the C<name()> method may end up
-returning C<undef> even when the record in question has an English name.
+Note that the only locale which is always present in the GeoIP2 data in "en".
+If you do not include this locale, the C<name()> method may end up returning
+C<undef> even when the record in question has an English name.
 
-Currently, the valid list of language codes is:
+Currently, the valid list of locale codes is:
 
 =over 8
 
@@ -444,7 +449,7 @@ spelling in English. In other words, English does not mean ASCII.
 
 =back
 
-Passing any other language code will result in an error.
+Passing any other locale code will result in an error.
 
 The default value for this argument is C<['en']>.
 
@@ -580,7 +585,7 @@ Graham Knop <haarg@haarg.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by MaxMind, Inc..
+This software is copyright (c) 2014 by MaxMind, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
